@@ -60,7 +60,7 @@ gint             dealerSpeed;
 
 gint             numHands;
 
-gchar            *game_file = "";
+const gchar      *game_file = "";
 gchar            *game_name;
 
 gboolean         allSettled = FALSE;
@@ -128,16 +128,16 @@ bj_game_file_to_name (const gchar* file)
 static const char *
 extension_pointer (const char * path)
 {
-        char * s, * t;
+        const char * s, * t;
         
         g_return_val_if_fail (path != NULL, NULL);
 
         /* get the dot in the last element of the path */
-        t = g_utf8_strrchr (path, -1, G_DIR_SEPARATOR);
+        t = strrchr (path, G_DIR_SEPARATOR);
         if (t != NULL)
-                s = g_utf8_strrchr (t, -1, '.');
+                s = strrchr (t, '.');
         else
-                s = g_utf8_strrchr (path, -1, '.');
+                s = strrchr (path, '.');
         
         if (s == NULL)
                 return path + strlen (path); /* There is no extension. */
@@ -190,7 +190,7 @@ bj_game_get_rules_name ()
         return game_name;
 }
 
-char *
+const char *
 bj_game_get_rules_file ()
 {
         return game_file;
@@ -434,7 +434,7 @@ bj_game_ensure_config_dir_exists (const char *dir)
 }
 
 static void
-bj_game_eval_installed_file (gchar *file)
+bj_game_eval_installed_file (const gchar *file)
 {
         char *installed_filename;
 
@@ -509,7 +509,7 @@ bj_game_cancel ()
 }
 
 void
-bj_game_new (gchar* file, guint *seedp )
+bj_game_new (const gchar* file, guint *seedp )
 {
         gint min_w, min_h;
 
