@@ -1,6 +1,5 @@
 import gtk, gnomeprint, gnomeprint.ui, math
 import sudoku, gsudoku
-from gtk_goodies.image_extras import html_to_tuple
 from gettext import gettext as _
 from gettext import ngettext
 
@@ -162,8 +161,6 @@ class SudokuDrawer (GridDrawer):
                             if trackers:
                                 tracker=trackers[0]
                                 color=self.sgd.get_tracker_color(tracker)
-                                color=html_to_tuple(color)
-                                color=[float(c)/256 for c in color]
                             else:
                                 color = self.alt_color
                         self.draw_number(
@@ -185,6 +182,7 @@ class SudokuPrinter:
                   sudokus_per_page=None,
                   dialog_parent=None
                   ):
+        self.drawn = False
         self.margin = margin
         self.sudokus_per_page=sudokus_per_page
         self.dialog_parent = dialog_parent
@@ -196,7 +194,6 @@ class SudokuPrinter:
         self.sudokus = sudokus
         #print 'Getting default config'
         self.job = gnomeprint.Job(gnomeprint.config_default())
-        self.drawn = False
 
     def run (self):
         self.dialog = gnomeprint.ui.Dialog(self.job,
@@ -276,7 +273,7 @@ class SudokuPrinter:
             drawer.draw_grid()
             drawer.draw_sudoku()
             count += 1
-        self.gpc.showpage()
+        if count: self.gpc.showpage()
         self.job.close()
         self.drawn = True
         
